% plots Fourier series examples using GUI

[object,figure]=gcbo;
handles=guihandles(figure);
nmax=get(handles.nmax,'String');
fundfreq=get(handles.fundfreq,'String');
dur=get(handles.dur,'String');
seriestype=get(handles.amph,'Value');
nmax=str2num(nmax);
fundfreq=str2num(fundfreq);
dur=str2num(dur);
fs=20*nmax*fundfreq;
axes(handles.axes1);

switch seriestype
    case(1) % odd harmonics, 1/n amplitude decay, 0 phase
        n=1:2:nmax;
        A=1./n;
        f=n*fundfreq;
        theta=zeros(1,length(n));
        [x,t]=sumcosine(A,f,theta,fs,dur);
        plot(t,x);
        xtitle=sprintf('Odd Harmonics, 1/n Amplitude Decay, 0 Phase, %3.0f Terms',nmax);
        title(xtitle);
        xlabel('Time t (sec)');
        ylabel('Signal x(t)');
        grid on;
        zoom on;
    case(2) % odd harmonics, +/- 1/n amplitude decay, 
        n=1:2:nmax;
        A=1./n;
        s=(-1).^((n-1)/2);
        A=A.*s;
        f=n*fundfreq;
        theta=zeros(1,length(n));
        [x,t]=sumcosine(A,f,theta,fs,dur);
        theta=(s-1)*180/2;
        plot(t,x);
        xtitle=sprintf('Odd Harmonics, +/- 1/n Amplitude Decay, %3.0f Terms',nmax);
        title(xtitle);
        xlabel('Time t (sec)');
        ylabel('Signal x(t)');
        grid on;
        zoom on;
    case(3) % odd harmonics, 1/n amplitude decay, random phase
        n=1:2:nmax;
        A=1./n;
        f=n*fundfreq;
        theta=2*pi*rand(1,length(n))-pi;
        [x,t]=sumcosine(A,f,theta,fs,dur);
        theta=180/pi*theta;
        plot(t,x);
        xtitle=sprintf('Odd Harmonics, 1/n Amplitude Decay, Random Phase %3.0f Terms',nmax);
        title(xtitle);
        xlabel('Time t (sec)');
        ylabel('Signal x(t)');
        grid on;
        zoom on;
    case(4) % odd harmonics, 1/n^2 amplitude decay, 0 phase
        n=1:2:nmax;
        A=1./n.^2;
        f=n*fundfreq;
        theta=zeros(1,length(n));
        [x,t]=sumcosine(A,f,theta,fs,dur);
        plot(t,x);
        xtitle=sprintf('Odd Harmonics, 1/n^2 Amplitude Decay, 0 Phase %3.0f Terms',nmax);
        title(xtitle);
        xlabel('Time t (sec)');
        ylabel('Signal x(t)');
        grid on;
        zoom on;
    case(5) % all harmonics, 1/n amplitude decay, 0 phase
        n=1:nmax;
        A=1./n;
        f=n*fundfreq;
        theta=zeros(1,length(n));
        [x,t]=sumcosine(A,f,theta,fs,dur);
        plot(t,x);
        xtitle=sprintf('All Harmonics, 1/n Amplitude Decay, 0 Phase %3.0f Terms',nmax);
        title(xtitle);
        xlabel('Time t (sec)');
        ylabel('Signal x(t)');
        grid on;
        zoom on;
    case(6) % all harmonics, 1/n amplitude decay, -pi/2 phase shift
        n=1:nmax;
        A=1./n;
        f=n*fundfreq;
        theta=-pi/2*ones(1,length(n));
        [x,t]=sumcosine(A,f,theta,fs,dur);
        theta=180/pi*theta;
        plot(t,x);
        xtitle=sprintf('All Harmonics, 1/n Amplitude Decay, -pi/2 Phase, %3.0f Terms',nmax);
        title(xtitle);
        xlabel('Time t (sec)');
        ylabel('Signal x(t)');
        grid on;
        zoom on;
    otherwise
        disp('Unknown series')
end

axes(handles.axes2);
spectpltmod(abs(A),f);
xlabel('Frequency kf_0 (Hz)');
ylabel('Amplitude A_k');
axis([0,max(f)+fundfreq,0,1]);
grid on;
zoom on;

axes(handles.axes3);
spectpltmod(theta,f);
xlabel('Frequency kf_0 (Hz)');
ylabel('Phase \theta_k (deg)');
axis([0,max(f)+fundfreq,-200,200]);
grid on;
zoom on;